@@ -5,7 +5,7 @@
 
 #if PyObjC_BUILD_RELEASE >= 1014
 /* The SDK included with Xcode 10 no longer includes a number
- * of header files, but does #incldue them in <oCarbon/Carbon.h>.
+ * of header files, but does #include them in <oCarbon/Carbon.h>.
  *
  * The defines below avoid trying to import these, which is
  * safe because we don't use any of the definitions from these files.
@@ -26,16 +26,15 @@ static PyMethodDef mod_methods[] = {
 };
 
 /* Python glue */
-static struct PyModuleDef mod_module = {
-     PyModuleDef_HEAD_INIT,
-     "_InputMethodKit",
-     NULL,
-     0,
-     mod_methods,
-     NULL,
-     NULL,
-     NULL,
-     NULL};
+static struct PyModuleDef mod_module = {PyModuleDef_HEAD_INIT,
+                                        "_InputMethodKit",
+                                        NULL,
+                                        0,
+                                        mod_methods,
+                                        NULL,
+                                        NULL,
+                                        NULL,
+                                        NULL};
 
 PyObject* PyInit__InputMethodKit(void);
 
@@ -43,7 +42,9 @@ PyObject* __attribute__((__visibility__("default"))) PyInit__InputMethodKit(void
 {
     PyObject* m;
     m = PyModule_Create(&mod_module);
-    if (!m) { return NULL; }
+    if (!m) {
+        return NULL;
+    }
 
     if (PyObjC_ImportAPI(m) == -1)
         return NULL;
